package gui;
import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;

import javax.swing.BorderFactory;
import javax.swing.ButtonGroup;
import javax.swing.DefaultComboBoxModel;
import javax.swing.DefaultListModel;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JTextField;
import javax.swing.border.Border;

public class FormPanel extends JPanel{
	
	private JLabel nameLabel;
	private JLabel occupationLabel;
	private JTextField nameField;
	private JTextField occupationField;
	private JButton okBtn;
	private FormListener formListener;
	private JList ageList;
	private JComboBox empCombo;
	private JCheckBox citizenCheck;
	private JTextField taxField;
	private JLabel taxLabel;
	
	private JRadioButton maleRadio;
	private JRadioButton femaleRadio;
	private ButtonGroup genderGroup;
	
	public FormPanel() {
		Dimension dim = getPreferredSize();//FormPanel preset size
		dim.width = 250;//overrides default preferred size
		setPreferredSize(dim);//forces layout manager to honor this setting
		
		nameLabel = new JLabel("Name: ");
		occupationLabel = new JLabel("Occupation: ");
		nameField = new JTextField(10);//10 specifies how wide textField should be
		occupationField = new JTextField(10);//assigns variables to parameters for input text
		ageList = new JList();
		empCombo = new JComboBox();
		citizenCheck = new JCheckBox();
		taxField = new JTextField(10);
		taxLabel = new JLabel("Tax ID: ");
		okBtn = new JButton("Ok");//submit button
		
		//Set up mnemonics
		okBtn.setMnemonic(KeyEvent.VK_O);
		
		nameLabel.setDisplayedMnemonic(KeyEvent.VK_N);
		nameLabel.setLabelFor(nameField);//tells program to set active input textField to nameField when Mnemonic is pressed
		
		maleRadio = new JRadioButton("Male");
		femaleRadio = new JRadioButton("Female");
		genderGroup = new ButtonGroup();
		maleRadio.setActionCommand("male");
		femaleRadio.setActionCommand("female");
		
		maleRadio.setSelected(true);//defaults radio selection to Male option upon application launch
		
		//set up gender radios
		genderGroup.add(maleRadio);
		genderGroup.add(femaleRadio);
		
		//set up tax ID
		taxLabel.setEnabled(false);
		taxField.setEnabled(false);
		//boolean variables that are conditions checked to enable taxField input and taxLabel highlightable (not greyed out)
		
		citizenCheck.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent arg0) {
				boolean isTicked = citizenCheck.isSelected();
				taxLabel.setEnabled(isTicked);
				taxField.setEnabled(isTicked);
			}
		});
		
		//set up list box
		DefaultListModel ageModel = new DefaultListModel();
		ageModel.addElement(new AgeCategory(0, "Under 18"));
		ageModel.addElement(new AgeCategory(1, "18 to 65"));
		ageModel.addElement(new AgeCategory(2, "Over 65"));
		ageList.setModel(ageModel);
		
		ageList.setPreferredSize(new Dimension(110, 70));
		ageList.setBorder(BorderFactory.createEtchedBorder());
		ageList.setSelectedIndex(1);
		
		//set up combo box
		DefaultComboBoxModel empModel = new DefaultComboBoxModel();
		empModel.addElement("employed");
		empModel.addElement("self-employed");
		empModel.addElement("unemployed");
		empCombo.setModel(empModel);
		empCombo.setSelectedIndex(0);
		empCombo.setEditable(false);
		
		okBtn.addActionListener(new ActionListener() {
			public void actionPerformed(ActionEvent e) {
				String name = nameField.getText();
				String occupation = occupationField.getText();
				AgeCategory ageCat = (AgeCategory)ageList.getSelectedValue();
				String empCat = (String)empCombo.getSelectedItem();
				String taxId = taxField.getText();
				boolean usCitizen = citizenCheck.isSelected();
				
				String gender = genderGroup.getSelection().getActionCommand();				
				
				System.out.println(empCat);
				
				FormEvent ev = new FormEvent(this, name, occupation, ageCat.getId(), empCat, taxId, usCitizen, gender);
				
				if(formListener != null) {
					formListener.formEventOccured(ev);
				}
			}
			
		});
		
		Border innerBorder = BorderFactory.createTitledBorder("Add Person");//Wraps above border in another border (margin) to increase size
		Border outerBorder = BorderFactory.createEmptyBorder(5, 5, 5, 5);//Establishes outer or invisible margin border with 5px all around
		setBorder(BorderFactory.createCompoundBorder(outerBorder, innerBorder));
		
		layoutComponents();
	}
	
	public void layoutComponents() {
		setLayout(new GridBagLayout());
		
		GridBagConstraints gc = new GridBagConstraints();//makes new variable with GridBagContraints method
		
		//FIRST ROW		
		gc.gridy = 0;		
			//nameLabel
			gc.weightx = 1;
			gc.weighty = .1;
			gc.gridx = 0;
			gc.fill = GridBagConstraints.NONE;
			gc.anchor = GridBagConstraints.LINE_END;
			gc.insets = new Insets(0,0,0,5);
			add(nameLabel, gc);
			//nameField
			gc.gridx = 1;
			gc.gridy = 0;
			gc.anchor = GridBagConstraints.LINE_START;
			gc.insets = new Insets(0,0,0,0);
			add(nameField, gc);
		
		//SECOND ROW		
		gc.gridy++;		
		gc.weightx = 1;
		gc.weighty = 0.1;		
			//occupationLabel
			gc.gridx = 0;
			gc.anchor = GridBagConstraints.LINE_END;
			gc.insets = new Insets(0,0,0,5);
			add(occupationLabel, gc);		
			//occupationField
			gc.gridx = 1;
			gc.insets = new Insets(0,0,0,0);
			gc.anchor = GridBagConstraints.LINE_START;
			add(occupationField, gc);
		
		//THIRD ROW		
		gc.gridy++;		
		gc.weightx = 1;
		gc.weighty = 0.2;
		
			//employmentLabel
			gc.gridx = 0;
			gc.insets = new Insets(0,0,0,5);
			gc.anchor = GridBagConstraints.LINE_END;
			add(new JLabel("Age: "), gc);
		
			//ageList
			gc.gridx = 1;
			gc.anchor = GridBagConstraints.FIRST_LINE_START;
			gc.insets = new Insets (0,0,0,0);
			add(ageList, gc);
			
		//FOURTH ROW		
		gc.gridy++;		
		gc.weightx = 1;
		gc.weighty = .2;
			//employmentLabel
			gc.gridx = 0;
			gc.insets = new Insets(0,0,0,5);
			gc.anchor = GridBagConstraints.FIRST_LINE_END;
			add(new JLabel("Employment: "), gc);
			//ageList
			gc.gridx = 1;
			gc.anchor = GridBagConstraints.FIRST_LINE_START;
			gc.insets = new Insets (0,0,0,0);
			add(empCombo, gc);
		
		//FIFTH ROW		
		gc.gridy++;		
		gc.weightx = 1;
		gc.weighty = .2;
			//employmentLabel
			gc.gridx = 0;
			gc.insets = new Insets(0,0,0,5);
			gc.anchor = GridBagConstraints.FIRST_LINE_END;
			add(new JLabel("US Citizen: "), gc);
			//ageList
			gc.gridx = 1;
			gc.anchor = GridBagConstraints.FIRST_LINE_START;
			gc.insets = new Insets (0,0,0,0);
			add(citizenCheck, gc);
			
			//FIFTH ROW		
			gc.gridy++;		
			gc.weightx = 1;
			gc.weighty = .2;
				//employmentLabel
				gc.gridx = 0;
				gc.insets = new Insets(0,0,0,5);
				gc.anchor = GridBagConstraints.FIRST_LINE_END;
				add(taxLabel, gc);
				//ageList
				gc.gridx = 1;
				gc.anchor = GridBagConstraints.FIRST_LINE_START;
				gc.insets = new Insets (0,0,0,0);
				add(taxField, gc);
				
			//SIXTH ROW		
			gc.gridy++;		
			gc.weightx = 1;
			gc.weighty = 0.05;
				//genderLabel
				gc.gridx = 0;
				gc.insets = new Insets(0,0,0,5);
				gc.anchor = GridBagConstraints.LINE_END;
				add(new JLabel("Gender: "), gc);
				//maleRadio
				gc.gridx = 1;
				gc.anchor = GridBagConstraints.FIRST_LINE_START;
				gc.insets = new Insets (0,0,0,0);
				add(maleRadio, gc);
				
			//SEVENTH ROW		
			gc.gridy++;		
			gc.weightx = 1;
			gc.weighty = .2;
				//femaleRadio
				gc.gridx = 1;
				gc.anchor = GridBagConstraints.FIRST_LINE_START;
				gc.insets = new Insets (0,0,0,0);
				add(femaleRadio, gc);
		
		//EIGHTH ROW		
		gc.gridy++;		
		gc.weightx = 1;
		gc.weighty = 2.0;		
			//okBtn
			gc.gridx = 1;
			gc.anchor = GridBagConstraints.FIRST_LINE_START;
			gc.insets = new Insets (0,0,0,0);
			add(okBtn, gc);	
	}
	
	public void setFormListener(FormListener listener) {
		this.formListener = listener;
	}
}

class AgeCategory{
	private int id;
	private String text;
	public AgeCategory(int id, String text) {
		this.id = id;
		this.text = text;
	}
	
	public String toString() {
		return text;
	}
	
	public int getId() {
		return id;
	}
}



