package gui;
import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;

import javax.swing.JCheckBoxMenuItem;
import javax.swing.JFileChooser;
import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JOptionPane;
import javax.swing.KeyStroke;

import controller.Controller;

public class MainFrame extends JFrame {

	private TextPanel textPanel;
	private Toolbar toolbar;// new for Tutorial06, declares Toolbar variable
	private FormPanel formPanel;
	private JFileChooser fileChooser;
	private Controller controller;
	private TablePanel tablePanel;

	public MainFrame() {
		super("Hello World");// Same as Hello World on Super class

//			setLayout(new BorderLayout());//different layout managers, we'll start with BorderLayout in MainFrame.java

		toolbar = new Toolbar();
		textPanel = new TextPanel();
		formPanel = new FormPanel();
		fileChooser = new JFileChooser();
		tablePanel = new TablePanel();
		
		controller = new Controller();
		
		tablePanel.setData(controller.getPeople());
		
		fileChooser.addChoosableFileFilter(new PersonFileFilter());

		setJMenuBar(createMenuBar());

		toolbar.setStringListener(new StringListener() {
			public void textEmitted(String text) {
				System.out.println(text);// Prints text on button to console
				textPanel.appendText(text);// Prints text on button to TextPanel (window)
			}
		});

		formPanel.setFormListener(new FormListener() {
			public void formEventOccured(FormEvent e) {
				controller.addPerson(e);
				tablePanel.refresh();
			}
		});

		add(formPanel, BorderLayout.WEST);// new for Tutorial09, places new FormPanel on left side of window
		add(toolbar, BorderLayout.NORTH);// new for Tutorial06, places toolbar object declared at top of JFrame window
		//add(tablePanel, BorderLayout.CENTER);
		//add(textPanel, BorderLayout.CENTER);

		setMinimumSize(new Dimension(500, 400));// Changes default size of JFrame window upon launch, minimum inserted
												// so input fields don't disappear
		
		setMinimumSize(new Dimension(500, 400));//can't make window smaller than this
		setSize(600, 500);
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);// Causes application to close when X is clicked
		setVisible(true);// JFrame isn't visible by default, this makes it visible
		// prefix frame. reference was removed from these three lines since it can now
		// be called by the parent class
	}

	private JMenuBar createMenuBar() {
			JMenuBar menuBar = new JMenuBar();			
			
			JMenu fileMenu = new JMenu("File");//creates File menu
			JMenuItem exportDataItem = new JMenuItem("Export Data...");
			JMenuItem importDataItem = new JMenuItem("Import Data...");
			JMenuItem exitItem = new JMenuItem("Exit");
			
			fileMenu.add(exportDataItem);
			fileMenu.add(importDataItem);
			fileMenu.addSeparator();
			fileMenu.add(exitItem);
			//adds all these items to File menu
			
			JMenu windowMenu = new JMenu("Window");//creates Window menu
			JMenu showMenu = new JMenu("Show");
			
			JCheckBoxMenuItem showFormItem = new JCheckBoxMenuItem("Person Form");
			showFormItem.setSelected(true);
			
			showMenu.add(showFormItem);
			windowMenu.add(showMenu);
			
			menuBar.add(fileMenu);//adds clickable File menu to menu bar
			menuBar.add(windowMenu);//adds clickable Window menu to menu bar
			
			showFormItem.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent ev) {
					JCheckBoxMenuItem menuItem = (JCheckBoxMenuItem)ev.getSource();
					
					formPanel.setVisible(menuItem.isSelected());
				}//all this hides formPanel if unchecked
			});
			
			fileMenu.setMnemonic(KeyEvent.VK_F);//Underlines F in String File, when Pressed, brings up File Menu
			exitItem.setMnemonic(KeyEvent.VK_X);//Underlines x in String Exit, when Pressed, exits window (as long as System.exit(0) is added as actionListener
			
			exitItem.setAccelerator(KeyStroke.getKeyStroke(KeyEvent.VK_X, ActionEvent.CTRL_MASK));//establikshes x as key to press for desired action, CTRL_MASK establishes desired modifier
			//Ctrl-X annotation is added to Exit entry in File menu
			
			importDataItem.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					if (fileChooser.showOpenDialog(MainFrame.this) == JFileChooser.APPROVE_OPTION){
						System.out.println(fileChooser.getSelectedFile());
					}
					System.out.println();
				}
			});
			
			exportDataItem.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent e) {
					if (fileChooser.showSaveDialog(MainFrame.this) == JFileChooser.APPROVE_OPTION){
						System.out.println(fileChooser.getSelectedFile());
					}
					System.out.println();
				}
			});
			
			
			exitItem.addActionListener(new ActionListener() {
				public void actionPerformed(ActionEvent arg0) {
					String text = JOptionPane.showInputDialog(MainFrame.this, "Enter your user name", "Enter User name", JOptionPane.OK_OPTION|JOptionPane.QUESTION_MESSAGE);
					System.out.println(text);//shows text input in above popup box, Cancel will return null
					
					int action = JOptionPane.showConfirmDialog(MainFrame.this, "Ya sure?", "Confirm Exit", JOptionPane.OK_CANCEL_OPTION);
//					  - MainFrame.this - refers to existing class
//					  - "Ya sure?" is message that appears in popup box
//					  - JOptionPane.OK_CANCEL_OPTION //adds Ok and Cancel buttons to popup window
									
					if(action == JOptionPane.OK_OPTION) {
						if(action == JOptionPane.OK_OPTION) {
						System.exit(0);//command to exit window, same as return 0 in c++
						}
					}//System.exit was put in if statement so that it only exits when Ok button in popup window is pressed. Before, Cancel would also exit.
				}
			});
			
			return menuBar;
		}
}
